@@ -11,6 +11,23 @@ from pkg_resources import resource_string, resource_exists, resource_filename
 import six
 
 
+_OPTIONAL_FUNCTIONS = (
+'''
+OM_uint32 gss_acquire_cred_with_password(
+  OM_uint32          *minor_status,
+  const gss_name_t   desired_name,
+  const gss_buffer_t password,
+  OM_uint32          time_req,
+  const gss_OID_set  desired_mechs,
+  gss_cred_usage_t   cred_usage,
+  gss_cred_id_t      *output_cred_handle,
+  gss_OID_set        *actual_mechs,
+  OM_uint32          *time_rec);
+''',
+)
+_OPTIONAL_DEFINES = ('GSS_C_DELEG_POLICY_FLAG', 'GSS_C_AF_INET6')
+
+
 def _detect_verify_args():
     source = '#include <gssapi/gssapi.h>'
     kwargs = defaultdict(list)
@@ -52,9 +69,9 @@ def _detect_verify_args():
     return source, final_kwargs
 
 
-def _is_defined(define, verify_args, verify_kwargs):
+def _is_verifiable(cdef, verify_args, verify_kwargs):
     ffi = FFI()
-    ffi.cdef("#define {0} ...".format(define))
+    ffi.cdef(cdef)
     try:
         ffi.verify(*verify_args, **verify_kwargs)
     except VerificationError:
@@ -141,6 +158,69 @@ def _guess_type(typedef, verify_args, verify_kwargs, assume_pointer=True):
         return 'struct { ...; }'
 
 
+def _kwargs_decode(input):
+    if isinstance(input, dict):
+        return {_kwargs_decode(key): _kwargs_decode(value) for key, value in input.items()}
+    elif isinstance(input, list):
+        return [_kwargs_decode(element) for element in input]
+    elif six.PY2 and isinstance(input, unicode):
+        return input.encode()
+    elif six.PY3 and isinstance(input, bytes):
+        return input.decode()
+    else:
+        return input
+
+
+def _read_header():
+    if resource_exists(__name__, 'autogenerated.cdef'):
+        generated_cdefs = resource_string(__name__, 'autogenerated.cdef').decode('utf-8')
+        # The first line (comment) is the verify settings, encoded
+        line = generated_cdefs.splitlines()[0]
+        settings = json.loads(base64.b64decode(line[3:-3].encode('ascii')).decode('utf-8'))
+        source = settings['source']
+        kwargs = _kwargs_decode(settings['kwargs'])
+    else:
+        cdefs = resource_string(__name__, 'cffi_gssapi.cdef').decode('utf-8')
+        source, kwargs = _detect_verify_args()
+        kwargs = _kwargs_decode(kwargs)
+        ptr_types_to_detect = ('gss_ctx_id_t', 'gss_cred_id_t', 'gss_name_t')
+        gen_types_to_detect = ('uid_t',)
+        generated_cdefs = '/* '
+        generated_cdefs += base64.b64encode(json.dumps({
+            'source': source,
+            'kwargs': kwargs
+        }).encode('utf-8')).decode('ascii')
+        generated_cdefs += ' */\n'
+        for define in _OPTIONAL_DEFINES:
+            test_cdef = '#define {0} ...\n'.format(define)
+            if _is_verifiable(test_cdef, [source], kwargs):
+                generated_cdefs += test_cdef
+        for p in ptr_types_to_detect:
+            guessed = _guess_type(p, [source], kwargs, True)
+            generated_cdefs += "typedef {0} {1};\n".format(guessed, p)
+        for t in gen_types_to_detect:
+            guessed = _guess_type(t, [source], kwargs, False)
+            generated_cdefs += "typedef {0} {1};\n".format(guessed, t)
+        # Now copy in the pre-written cdefs
+        generated_cdefs += "\n"
+        generated_cdefs += cdefs
+        generated_cdefs += "\n\n"
+        # Now add any optional functions which must come after main cdefs
+        for func in _OPTIONAL_FUNCTIONS:
+            test_cdefs = generated_cdefs + func
+            if _is_verifiable(test_cdefs, [source], kwargs):
+                generated_cdefs = test_cdefs
+        with open(resource_filename(__name__, 'autogenerated.cdef'), 'wb') as settings_file:
+            settings_file.write(generated_cdefs.encode('utf-8'))
+    return generated_cdefs, source, kwargs
+
+
+_cdefs, _source, _kwargs = _read_header()
+ffi = FFI()
+ffi.cdef(_cdefs)
+C = ffi.verify(_source, **_kwargs)
+
+
 def GSS_CALLING_ERROR(x):
     return (x & (C.GSS_C_CALLING_ERROR_MASK << C.GSS_C_CALLING_ERROR_OFFSET))
 
@@ -158,61 +238,6 @@ def GSS_ERROR(x):
                  (C.GSS_C_ROUTINE_ERROR_MASK << C.GSS_C_ROUTINE_ERROR_OFFSET)))
 
 
-def _kwargs_decode(input):
-    if isinstance(input, dict):
-        return {_kwargs_decode(key): _kwargs_decode(value) for key, value in input.items()}
-    elif isinstance(input, list):
-        return [_kwargs_decode(element) for element in input]
-    elif six.PY2 and isinstance(input, unicode):
-        return input.encode()
-    elif six.PY3 and isinstance(input, bytes):
-        return input.decode()
-    else:
-        return input
-
-
 def _buf_to_str(buf):
     """Converts a gss_buffer_desc containing a char * string to Python bytes"""
     return ffi.buffer(buf.value, buf.length)[:]
-
-
-def _read_header():
-    cdefs = resource_string(__name__, 'cffi_gssapi.cdef').decode('utf-8')
-
-    if resource_exists(__name__, 'autogenerated.cdef'):
-        generated_cdefs = resource_string(__name__, 'autogenerated.cdef').decode('utf-8')
-        # The first line (comment) is the verify settings, encoded
-        line = generated_cdefs.splitlines()[0]
-        settings = json.loads(base64.b64decode(line[3:-3].encode('ascii')).decode('utf-8'))
-        source = settings['source']
-        kwargs = _kwargs_decode(settings['kwargs'])
-    else:
-        source, kwargs = _detect_verify_args()
-        kwargs = _kwargs_decode(kwargs)
-        optional_defines = ('GSS_C_DELEG_POLICY_FLAG', 'GSS_C_AF_INET6')
-        ptr_types_to_detect = ('gss_ctx_id_t', 'gss_cred_id_t', 'gss_name_t')
-        gen_types_to_detect = ('uid_t',)
-        generated_cdefs = '/* '
-        generated_cdefs += base64.b64encode(json.dumps({
-            'source': source,
-            'kwargs': kwargs
-        }).encode('utf-8')).decode('ascii')
-        generated_cdefs += ' */\n'
-        for define in optional_defines:
-            if _is_defined(define, [source], kwargs):
-                generated_cdefs += '#define {0} ...\n'.format(define)
-        for p in ptr_types_to_detect:
-            guessed = _guess_type(p, [source], kwargs, True)
-            generated_cdefs += "typedef {0} {1};\n".format(guessed, p)
-        for t in gen_types_to_detect:
-            guessed = _guess_type(t, [source], kwargs, False)
-            generated_cdefs += "typedef {0} {1};\n".format(guessed, t)
-        with open(resource_filename(__name__, 'autogenerated.cdef'), 'wb') as settings_file:
-            settings_file.write(generated_cdefs.encode('utf-8'))
-    return generated_cdefs + cdefs, source, kwargs
-
-
-_cdefs, _source, _kwargs = _read_header()
-ffi = FFI()
-ffi.cdef(_cdefs)
-C = ffi.verify(_source, **_kwargs)
